@@ -1,4 +1,4 @@
-from pydantic import BaseModel, Field
+from pydantic import BaseModel, Field, model_validator
 from typing import List, Any, ClassVar
 from enum import StrEnum
 from letschatty.models.base_models.ai_agent_component import AiAgentComponent
@@ -28,4 +28,16 @@ class ChatExample(AiAgentComponent):
         result = ""
         for element in self.content:
             result += element.to_string() + "\n"
-        return result
\ No newline at end of file
+        return result
+
+    @model_validator(mode='after')
+    def check_that_test_cases_are_only_for_one_ai_agent(self):
+        """If a chat example is NOT a training example, it must have an only_ai_agent_id"""
+        if not self.is_training_example and self.is_only_for_one_ai_agent:
+            raise ValueError("Chat example must have an ai_agent_id if it is not a training example")
+        return self
+
+    @property
+    def is_only_for_quality_tests(self) -> bool:
+        """Check if the chat example is only for quality tests"""
+        return not self.is_training_example
\ No newline at end of file
