@@ -4,6 +4,7 @@ from typing import TYPE_CHECKING, Dict, List, Generic, TypeVar, Type, Optional,
 from bson.objectid import ObjectId
 from pymongo.collection import Collection
 from pymongo.database import Database
+from motor.motor_asyncio import AsyncIOMotorDatabase, AsyncIOMotorCollection
 
 from letschatty.models.chat.chat import Chat
 from ...models.base_models.chatty_asset_model import ChattyAssetModel, CompanyAssetModel, ChattyAssetPreview
@@ -26,8 +27,14 @@ P = TypeVar('P', bound=ChattyAssetPreview)
 class ChattyAssetCollectionInterface(Generic[T, P], ABC):
     def __init__(self, database: str, collection: str, connection: MongoConnection, type: Type[T], preview_type: Optional[Type[P]] = None):
         logger.info(f"Initializing collection {collection} in database {database}")
+        # Sync database and collection (existing)
         self.db: Database = connection.client[database]
         self.collection: Collection = connection.client[database][collection]
+
+        # NEW: Async database and collection
+        self.async_db: AsyncIOMotorDatabase = connection.async_client[database]
+        self.async_collection: AsyncIOMotorCollection = connection.async_client[database][collection]
+
         self.type = type
         self.preview_type = preview_type
     @abstractmethod
@@ -35,49 +42,79 @@ class ChattyAssetCollectionInterface(Generic[T, P], ABC):
         """Factory method to create instance from data"""
         pass
 
-    def insert(self, asset: T) -> StrObjectId:
+    # All methods are now async-only for better performance
+    async def insert(self, asset: T) -> StrObjectId:
+        """Async insert operation"""
         if not isinstance(asset, self.type):
             raise ValueError(f"Asset must be of type {self.type.__name__}")
         document = asset.model_dump_json(serializer=SerializerType.DATABASE)
         logger.debug(f"Inserting document: {document}")
-        result = self.collection.insert_one(document)
+        result = await self.async_collection.insert_one(document)
         if not result.inserted_id:
             raise Exception("Failed to insert document")
         logger.debug(f"Inserted document with id {result.inserted_id}")
         return result.inserted_id
 
-    def update(self, asset: T) -> StrObjectId:
+    async def update(self, asset: T) -> StrObjectId:
+        """Async update operation"""
         logger.debug(f"Updating document with id {asset.id}")
         if not isinstance(asset, self.type):
             raise ValueError(f"Asset must be of type {self.type.__name__}")
         asset.update_now()
         document = asset.model_dump_json(serializer=SerializerType.DATABASE)
-        document.pop('_id', None)  # Still needed
-        result = self.collection.update_one({"_id": ObjectId(asset.id)}, {"$set": document})
+        document.pop('_id', None)
+        result = await self.async_collection.update_one(
+            {"_id": ObjectId(asset.id)},
+            {"$set": document}
+        )
         if result.matched_count == 0:
             raise NotFoundError(f"No document found with id {asset.id}")
         if result.modified_count == 0:
             logger.debug(f"No changes were made to the document with id {asset.id} probably because the values were the same")
         return asset.id
 
-    def get_by_id(self, doc_id: str) -> T:
-        logger.debug(f"Getting document with id {doc_id} from collection {self.collection.name} and db {self.db.name}")
-        doc = self.collection.find_one({"_id": ObjectId(doc_id)})
-
+    async def get_by_id(self, doc_id: str) -> T:
+        """Get by ID operation"""
+        logger.debug(f"Getting document with id {doc_id} from collection {self.async_collection.name}")
+        doc = await self.async_collection.find_one({"_id": ObjectId(doc_id)})
         if doc:
             return self.create_instance(doc)
         else:
-            raise NotFoundError(f"No document found with id {doc_id} in db collection {self.collection.name} and db {self.db.name}")
+            raise NotFoundError(f"No document found with id {doc_id} in collection")
 
-    def get_docs(self, company_id:Optional[StrObjectId], query = {}, limit = 0) -> List[T]:
-        logger.debug(f"Getting documents from collection {self.collection.name} with company_id {company_id} and query {query}")
+    async def get_docs(self, company_id: Optional[StrObjectId], query={}, limit=0) -> List[T]:
+        """Get multiple documents operation"""
+        logger.debug(f"Getting documents from collection with company_id {company_id} and query {query}")
         if company_id:
-            query = query.copy()  # Create a copy to avoid modifying the original
+            query = query.copy()
             query["company_id"] = company_id
-        docs = list(self.collection.find(filter=query).limit(limit))
-        logger.debug(f"Found {len(docs)} documents in collection {self.collection.name}")
+        cursor = self.async_collection.find(filter=query)
+        if limit:
+            cursor = cursor.limit(limit)
+        docs = await cursor.to_list(length=limit if limit > 0 else None)
+        logger.debug(f"Found {len(docs)} documents")
         return [self.create_instance(doc) for doc in docs]
 
+    async def delete(self, doc_id: str, deletion_type: DeletionType = DeletionType.LOGICAL) -> StrObjectId:
+        """Delete operation"""
+        logger.debug(f"Deleting document with id {doc_id} - deletion type: {deletion_type}")
+        if deletion_type == DeletionType.LOGICAL:
+            result = await self.async_collection.update_one(
+                {"_id": ObjectId(doc_id)},
+                {"$set": {"deleted_at": datetime.now(ZoneInfo("UTC")), "updated_at": datetime.now(ZoneInfo("UTC"))}}
+            )
+            if result.modified_count == 0:
+                raise NotFoundError(f"No document found with id {doc_id}")
+            return doc_id
+        elif deletion_type == DeletionType.PHYSICAL:
+            result = await self.async_collection.delete_one({"_id": ObjectId(doc_id)})
+            if result.deleted_count == 0:
+                raise NotFoundError(f"No document found with id {doc_id}")
+            return doc_id
+        else:
+            raise ValueError(f"Invalid deletion type: {deletion_type}")
+
+    # Additional methods - keeping these sync as they're less critical
     def get_preview_docs(self, projection = {}, all=True) -> List[P]:
         """We get the previews of all the documents in the collection for all companies"""
         if not self.preview_type:
@@ -98,18 +135,3 @@ class ChattyAssetCollectionInterface(Generic[T, P], ABC):
         docs = self.collection.find(query)
         return [self.create_instance(doc) for doc in docs]
 
-    def delete(self, doc_id: str, deletion_type : DeletionType = DeletionType.LOGICAL) -> StrObjectId:
-        logger.debug(f"Deleting document with id {doc_id} - deletion type: {deletion_type}")
-        if deletion_type == DeletionType.LOGICAL:
-            result = self.collection.update_one({"_id": ObjectId(doc_id)}, {"$set": {"deleted_at": datetime.now(ZoneInfo("UTC")), "updated_at": datetime.now(ZoneInfo("UTC"))}})
-            if result.modified_count == 0:
-                raise NotFoundError(f"No document found with id {doc_id}")
-            return doc_id
-        elif deletion_type == DeletionType.PHYSICAL:
-            result = self.collection.delete_one({"_id": ObjectId(doc_id)})
-            if result.deleted_count == 0:
-                raise NotFoundError(f"No document found with id {doc_id}")
-            return doc_id
-        else:
-            raise ValueError(f"Invalid deletion type: {deletion_type}")
-
