@@ -1,7 +1,7 @@
 from letschatty.models.chat.chat import Chat
 from letschatty.models.company.assets.ai_agents_v2.chat_example import ChatExample
 from typing import List
-from letschatty.models.company.assets.ai_agents_v2.chatty_ai_agent import ChattyAIAgent
+from letschatty.models.company.assets.ai_agents_v2.chatty_ai_agent import ChattyAIAgent, N8NWorkspaceAgentType
 from letschatty.models.company.assets.ai_agents_v2.chain_of_thought_in_chat import ChainOfThoughtInChatTrigger
 from letschatty.models.company.assets.ai_agents_v2.chatty_ai_mode import ChattyAIMode
 from letschatty.models.company.assets.ai_agents_v2.faq import FAQ
@@ -30,10 +30,20 @@ class ContextBuilder:
         context += f"\nHere's your desired behavior and personality: {agent.personality}"
         context += f"\nYour answers should be in the same lenguage as the user's messages. Default lenguage is Spanish."
         context += f"\nYour overall general objective is: {agent.general_objective}"
+        context += ContextBuilder.agent_type_prompt(agent)
         context += f"\nAs for the format of your answer: We want you to be as human as possible. When the answer requires it for redability, split it into max 3 messages that make sense. You are also to use line breaks inside each message to make it more readable."
         context += f"\n\n{ChattyAIMode.get_context_for_mode(mode_in_chat)}"
         return context
 
+    @staticmethod
+    def agent_type_prompt(agent: ChattyAIAgent) -> str:
+        if agent.n8n_workspace_agent_type == N8NWorkspaceAgentType.CALENDAR_SCHEDULER:
+            context = f"\nYou are a calendar scheduler agent. You need to use the scheduling rules provided by the company in order to schedule an appointment or meeting."
+            context += f"\nThe scheduling rules are: {agent.n8n_workspace_agent_type_parameteres.scheduling_rules}" if agent.n8n_workspace_agent_type_parameteres.scheduling_rules else ""
+            return context
+        else:
+            return ""
+
     @staticmethod
     def contexts_prompt(contexts: List[ContextItem]) -> str:
         context = "This is your knowleadge base, feel free to use it to answer the user's question."
@@ -64,7 +74,11 @@ class ContextBuilder:
         context += "\nNEVER talk about a subject other than the specified in your objective / contexts / prompt. If asked about something else, politely say that that's not within your scope and resume the desired conversation workflow."
         context += "\nNEVER ask the user for information that you already have."
         context += "\nDo not ask for the user phone number, you're already talking through WhatsApp."
-        context += "\nNEVER repeat the same information unless the user asks for it. If you think the user is asking for the same information, try to sumarize it and ask if that suits their needs. If not, offer them to escalate the question to a human and call the human_handover tool."
+        context += "\nNEVER repeat the same information to the user."
+        context += "\nNEVER GREET THE USER TWICE IN THE SAME CONVERSATION, ONLY ONCE."
+        context += "\nNEVER INCLUDE YOUR CHAIN OF THOUGHT IN THE MESSAGES YOU SEND TO THE USER. THAT'S FOR INTERNAL USE ONLY."
+        context += "\nMESSAGES SHOULD BE READABLE, KEEP IT SIMPLE AND NATURAL, DON'T OVEREXPLAIN NOR ADD IRRELEVANT DETAILS. FOCUS ON THE USER'S QUESTION AND ANSWER IT AS BEST AS YOU CAN, FOLLOWING THE COMPANY'S PERSONALITY, RULES, OBJECTIVE AND EXAMPLES."
+
         for rule in agent.unbreakable_rules:
             context += f"\n{rule}"
         return context
